/*
 * Copyright 2013 (c) Anna Schumaker.
 *
 * The playlist manager is in charge of the various playlists Ocarina
 * knows about.  This code also manages a special queue used by the GUI
 * to display the tracks in each playlist.
 */
#ifndef OCARINA_CORE_PLAYLIST_H
#define OCARINA_CORE_PLAYLIST_H

#include <core/playlists/type.h>
#include <core/queue.h>


/* Called to initialize the playlist manager. */
void playlist_init(struct queue_ops *);

/* Called to deinitialize the playlist manager. */
void playlist_deinit();


/* Called to add a track to a playlist. */
bool playlist_add(const gchar *, struct track *);

/* Called to remove a track from a playlist. */
bool playlist_remove(const gchar *, struct track *);

/* Called to update tracks on a playlist. */
void playlist_update(const gchar *);


/* Called to check if a specific track is in the playlist. */
bool playlist_has(const gchar *, struct track *);

/* Called to find the number of tracks in the playlist. */
unsigned int playlist_size(const gchar *);


/* Called to set the playlist's random flag. */
void playlist_set_random(const gchar *, bool);

/* Called to check the playlist's random flag. */
bool playlist_get_random(const gchar *);

/* Called to change the sort order of the playlist. */
void playlist_sort(const gchar *, enum compare_t, bool);


/* Called to get the next track from the default playlist. */
struct track *playlist_next(void);

/* Called to get a previously played track. */
struct track *playlist_prev(void);


/* Called to access the playlist queue. */
struct queue *playlist_get_queue(const gchar *);

#endif /* OCARINA_CORE_PLAYLIST_H */
